@@ -13,8 +13,8 @@
 G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (2)
-#define SOUP_MINOR_VERSION (66)
-#define SOUP_MICRO_VERSION (3)
+#define SOUP_MINOR_VERSION (68)
+#define SOUP_MICRO_VERSION (4)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
     (SOUP_MAJOR_VERSION > (major) || \
@@ -67,6 +67,7 @@ G_BEGIN_DECLS
 #define SOUP_VERSION_2_58 (G_ENCODE_VERSION (2, 58))
 #define SOUP_VERSION_2_62 (G_ENCODE_VERSION (2, 62))
 #define SOUP_VERSION_2_66 (G_ENCODE_VERSION (2, 66))
+#define SOUP_VERSION_2_68 (G_ENCODE_VERSION (2, 68))
 
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
@@ -389,6 +390,12 @@ G_BEGIN_DECLS
 # define SOUP_AVAILABLE_IN_2_66                 _SOUP_EXTERN
 #endif
 
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_2_68
+# define SOUP_AVAILABLE_IN_2_68                 G_UNAVAILABLE(2, 68) _SOUP_EXTERN
+#else
+# define SOUP_AVAILABLE_IN_2_68                 _SOUP_EXTERN
+#endif
+
 SOUP_AVAILABLE_IN_2_42
 guint    soup_get_major_version (void);
 
